#[non_exhaustive]pub struct Attribute {
pub location: AttributeLocation,
pub punct: Punct,
pub tokens: Group,
}Expand description
An attribute for the given struct, enum, field, etc
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.location: AttributeLocationThe location this attribute was parsed at
punct: PunctThe punct token of the attribute. This will always be Punct('#')
tokens: GroupThe group of tokens of the attribute. You can parse this to get your custom attributes.