Struct virtue::generate::Impl [−][src]
pub struct Impl<'a> { /* fields omitted */ }Expand description
A helper struct for implementing functions for a given struct or enum.
Implementations
Add a function to the trait implementation.
generator.impl().generate_fn("bar") results in code like:
ⓘ
impl <struct or enum> {
fn bar() {}
}See FnBuilder for more options, as well as information on how to fill the function body.